"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleError = exports.handleAPIError = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const iFunnyError_1 = require("./iFunnyError");
const iFunnyErrorCodes_1 = require("./iFunnyErrorCodes");
const Methods_1 = require("../utils/Methods");
function handleCaptcha(data) {
    return iFunnyError_1.iFunnyError.new(iFunnyErrorCodes_1.iFunnyErrorCodes.CaptchaRequired, data);
}
/**
 * Handles bad requests errors
 * @param error Bad request error data
 * @returns
 */
function handleBadRequest(error) {
    switch (error.error_description) {
        case "Invalid user id":
            // ? User with that ID does not exist
            return null;
        default:
            return iFunnyError_1.iFunnyError.new(iFunnyErrorCodes_1.iFunnyErrorCodes.UnknownError, error.error_description);
    }
}
/**
 * Handles an error returned by the iFunny error
 * @param error {@link RESTAPIErrorResponse}
 * @returns
 */
function handleAPIError(error) {
    switch (error.error) {
        case ifunny_api_types_1.IFUNNY_ERRORS.BAD_REQUEST:
            // @ts-ignore
            return handleBadRequest(error);
        case ifunny_api_types_1.IFUNNY_ERRORS.CAPTCHA_REQUIRED:
            return handleCaptcha(error);
        default:
            return iFunnyError_1.iFunnyError.new(iFunnyErrorCodes_1.iFunnyErrorCodes.UnknownError, error.error_description);
    }
}
exports.handleAPIError = handleAPIError;
/**
 * Handles errors thrown when making axios requests
 * @param error Error to handle
 * @returns `null` or custom iFunnyError
 */
function handleError(error) {
    if (!(0, Methods_1.isAxiosError)(error)) {
        return iFunnyError_1.iFunnyError.unknown(error);
    }
    if (error.response?.data) {
        return handleAPIError(error.response.data);
    }
    return iFunnyError_1.iFunnyError.new(iFunnyErrorCodes_1.iFunnyErrorCodes.UncaughtAxiosError, error.message);
}
exports.handleError = handleError;
//# sourceMappingURL=ErrorHandler.js.map