"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.iFunnyErrorMessage = exports.iFunnyRangeError = exports.iFunnyTypeError = exports.iFunnyError = void 0;
const Messages_1 = require("./Messages");
const iFunnyErrorCodes_1 = require("./iFunnyErrorCodes");
function makeError(Base) {
    var _iFunnyError__code, _a;
    /**
     * A class for representing an error thrown by iFunny.ts
     */
    return _a = class iFunnyError extends Base {
            /**
             * @param code The error code for the error
             * @param args Args to pass into the message formatter function
             */
            constructor(code, ...args) {
                super(message(code, args));
                /**
                 * The error code for the error
                 */
                _iFunnyError__code.set(this, void 0);
                __classPrivateFieldSet(this, _iFunnyError__code, code, "f");
                Error.captureStackTrace?.(this, iFunnyError);
            }
            /**
             * The error code for the error
             */
            get code() {
                return __classPrivateFieldGet(this, _iFunnyError__code, "f");
            }
            /**
             * The type of error
             */
            get error() {
                return iFunnyErrorCodes_1.iFunnyErrorCodes[this.code];
            }
            /**
             * The name of the error
             */
            get name() {
                return `iFunny${super.name} - ${iFunnyErrorCodes_1.iFunnyErrorCodes[this.code]} [${this.code}]`;
            }
            createMessage(code, ...args) {
                return message(code, ...args);
            }
            static new(code, ...args) {
                return new iFunnyError(code, ...args);
            }
            /**
             * Easily create an unknown error
             * @param error Unknown error to turn into iFunny Error
             * @returns
             */
            static unknown(error) {
                return iFunnyError.new(iFunnyErrorCodes_1.iFunnyErrorCodes.UnknownError, error);
            }
        },
        _iFunnyError__code = new WeakMap(),
        _a;
}
/**
 * Format the message for an error.
 * @param code The error code
 * @param args Arguments to pass for util format or as function args
 * @returns Formatted string
 */
function message(code, ...args) {
    if (typeof code !== "number")
        throw new Error("Error code must be a valid iFunnytsErrorCode");
    const msg = Messages_1.Messages[code];
    if (!msg)
        throw new Error(`An invalid error code was used: ${code}.`);
    // @ts-ignore
    if (typeof msg === "function")
        return msg(...args); // TODO: Fix this resolving to 1 function instead of union of functions
    return msg;
}
exports.iFunnyError = makeError(Error);
exports.iFunnyTypeError = makeError(TypeError);
exports.iFunnyRangeError = makeError(RangeError);
exports.iFunnyErrorMessage = message;
//# sourceMappingURL=iFunnyError.js.map