"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Ban = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const Base_1 = require("./Base");
const User_1 = require("./User");
/**
 * Represents a Ban on iFunny
 */
class Ban extends Base_1.Base {
    /**
     * @param client The Client instance
     * @param user User or Id of the user that the ban belongs to
     * @param id Id of the ban itself
     * @param payload Payload of the ban if applicable
     */
    constructor(client, user, id, payload = {}) {
        super(client, id, payload);
        this._user = user instanceof User_1.User ? user : new User_1.User(client, user);
        this.payload = payload;
        this.endpoint_url = ifunny_api_types_1.Endpoints.bans(this._user.id, id);
    }
    /**
     * Timestamp (in seconds) of when it expires
     */
    get expiresAtTimestamp() {
        let time = this.get("date_until");
        return typeof time === "number" ? time * 1000 : null;
    }
    /**
     * Date object of when the ban expires
     */
    get expiresAt() {
        let time = this.expiresAtTimestamp;
        return time ? new Date(time) : null;
    }
    /**
     * How long (in seconds) until the ban expires
     */
    get expiresInTimestamp() {
        let time = this.expiresAtTimestamp;
        return time ? time - new Date().getTime() : null;
    }
    /**
     * Date object of how much time is left until the ban expires
     */
    get expiresIn() {
        let time = this.expiresInTimestamp;
        return time ? new Date(time) : null;
    }
    /**
     * The type of the ban
     */
    get type() {
        return this.get("type");
    }
    /**
     * User that the ban belongs to
     */
    get user() {
        return this._user;
    }
}
exports.Ban = Ban;
//# sourceMappingURL=Ban.js.map