"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Base = void 0;
const DefaultObjectEndpoint = "/account";
/**
 * Base class for all structures.
 */
class Base {
    /**
     * @param client The client instance
     * @param payload The payload of the object
     */
    constructor(client, id, payload = {}) {
        /**
         * Endpoint url the object will request to
         */
        this._endpoint_url = DefaultObjectEndpoint;
        this._client = client;
        this._payload = payload ?? { id: id };
    }
    /**
     * The client instance attached to the Object
     */
    get client() {
        return this._client;
    }
    /**
     * Get the payload of the object
     */
    get payload() {
        return this._payload;
    }
    /**
     * Updates the payload of the object.
     * @param payload The payload to merge into the current instance
     * @returns The current instance
     */
    set payload(payload) {
        this._payload = Object.assign(this.payload, payload);
    }
    /**
     * Endpoint url for requests to update the payload
     */
    get endpoint_url() {
        return this._endpoint_url;
    }
    set endpoint_url(value) {
        this._endpoint_url = `${value}`;
    }
    /**
     * Fetches the objects data from it's endpoint
     * @returns The instance of the object
     */
    async fetch() {
        const response = await this.client.instance.get(this.endpoint_url);
        return (this.payload = response.data.data);
    }
    /**
     * Gets the value from the payload from its key
     * @param key The key to get the value of
     * @returns
     */
    get(key) {
        // @ts-ignore
        return this.payload[key] ?? null;
    }
    /**
     * The unique id of the object
     */
    get id() {
        return this.get("id");
    }
    /**
     * Creates a new instance of the same structure with the same payload.
     * @returns A clone of the current instance
     */
    _clone() {
        return Object.assign(Object.create(this), this);
    }
    valueOf() {
        return this.id;
    }
    /**
     *
     * @returns Converts the
     */
    toJSON() {
        return JSON.stringify(this.payload, null, 2);
    }
}
exports.Base = Base;
//# sourceMappingURL=Base.js.map