import { AxiosInstance, AxiosRequestHeaders } from "axios";
import { APIClientUser as ClientPayload } from "@ifunny/ifunny-api-types";
import { EventEmitter } from "eventemitter3";
export interface BaseClientConfig {
    userAgent: string;
    basic: string;
    bearer: string;
    headers: AxiosRequestHeaders;
    clientId: string;
    clientSecret: string;
}
export declare type BaseClientOptions = Partial<BaseClientConfig>;
/**
 * Base Client for the Client to extend
 * @extends EventEmitter
 */
export declare class BaseClient extends EventEmitter {
    /**
     * The axios instance used for requests
     */
    readonly instance: AxiosInstance;
    protected _payload: Partial<ClientPayload>;
    protected _basic: string;
    protected _bearer: string | null;
    constructor(options?: BaseClientOptions, payload?: Partial<ClientPayload>);
    /**
     * The authorization string used for requests
     */
    get authorization(): string;
    /**
     * Gets the payload
     */
    get payload(): Partial<ClientPayload>;
    set payload(value: Partial<ClientPayload>);
    /**
     * Calls eval with the client set as the "this" context.
     * @param script The script to evaluate
     * @returns The result of the script
     */
    protected _eval(script: string): any;
    /**
     * Paginates through items in a REST API endpoint.
     * @param url The url to get
     * @param key The key to get the array of values from
     * @param params The params to pass to the url
     * @yields The value of the key
     */
    protected paginate<T extends unknown>(url: string, key: string, params?: any): AsyncGenerator<T>;
}
//# sourceMappingURL=BaseClient.d.ts.map