import { BaseClient, BaseClientConfig } from "./BaseClient";
import { APIClientUser as ClientPayload } from "@ifunny/ifunny-api-types";
import { If } from "../utils/Util";
import { UserManager } from "../managers/UserManager";
interface ClientConfig extends Partial<BaseClientConfig> {
}
/**
 * Client for the Discord API.
 * @extends BaseClient
 */
export declare class Client<Authorized extends boolean = boolean> extends BaseClient {
    /**
     * User manager object
     */
    private _users;
    constructor(config?: ClientConfig, payload?: Partial<ClientPayload>);
    get basic(): string;
    set basic(value: string);
    /**
     * The bearer token for the client
     */
    get bearer(): If<Authorized, string, null>;
    /**
     * Sets the bearer token for the client. If set to null, the client will not use a bearer token.
     */
    set bearer(value: string | null);
    /**
     * Is the client using a bearer token to make requests?
     */
    isAuthorized(): this is Client<true>;
    /**
     * Updates the Client's payload
     * @returns The Client instance
     */
    fetch(): Promise<this>;
    /**
     * The client's user manager
     */
    get users(): UserManager;
    /**
     * Logs into iFunny with an Email and Password\
     * If you already have a bearer token, don't use this method
     * @param email The email to login with
     * @param password The password to login with
     * @returns The instance of the client
     */
    login(email: string, password: string): Promise<this>;
    /**
     * Signs up for an iFunny account.
     * @param nick The nick of the account to sign up with. Checks if the nick is taken.
     * @param email The email to sign up with. Checks if the email is taken.
     * @param password The password to sign up with
     * @param login Should the client login after sign up?
     * @returns The instance of the client
     */
    signUp(nick: string, email: string, password: string, acceptMailOffers?: boolean, login?: boolean): Promise<this>;
}
export default Client;
//# sourceMappingURL=Client.d.ts.map