import { APIBan as BanPayload } from "@ifunny/ifunny-api-types";
import { Base } from "./Base";
import { Client } from "../client/Client";
import { User } from "./User";
/**
 * Represents a Ban on iFunny
 */
export declare class Ban extends Base<BanPayload> {
    /**
     * Id of the user the ban is attached to
     */
    private readonly _user;
    /**
     * @param client The Client instance
     * @param user User or Id of the user that the ban belongs to
     * @param id Id of the ban itself
     * @param payload Payload of the ban if applicable
     */
    constructor(client: Client, user: User | string, id: string, payload?: Partial<BanPayload>);
    /**
     * Timestamp (in seconds) of when it expires
     */
    get expiresAtTimestamp(): number | null;
    /**
     * Date object of when the ban expires
     */
    get expiresAt(): Date | null;
    /**
     * How long (in seconds) until the ban expires
     */
    get expiresInTimestamp(): number | null;
    /**
     * Date object of how much time is left until the ban expires
     */
    get expiresIn(): Date | null;
    /**
     * The type of the ban
     */
    get type(): "other" | "content_creation" | "chat_access" | "subscribing" | "comment_creation" | "repubing" | "profile_access" | "smiling" | "collective_shadow" | null;
    /**
     * User that the ban belongs to
     */
    get user(): User;
}
//# sourceMappingURL=Ban.d.ts.map