import { APIBasePayload } from "@ifunny/ifunny-api-types";
import { Client } from "../client/Client";
/**
 * Base class for all structures.
 */
export declare class Base<Payload extends APIBasePayload> {
    /**
     * Client instance attached to the Object
     */
    private readonly _client;
    /**
     * The payload of the object.
     */
    protected _payload: Partial<Payload>;
    /**
     * Endpoint url the object will request to
     */
    private _endpoint_url;
    /**
     * @param client The client instance
     * @param payload The payload of the object
     */
    constructor(client: Client, id: string, payload?: Partial<Payload>);
    /**
     * The client instance attached to the Object
     */
    get client(): Client<boolean>;
    /**
     * Get the payload of the object
     */
    get payload(): Partial<Payload>;
    /**
     * Updates the payload of the object.
     * @param payload The payload to merge into the current instance
     * @returns The current instance
     */
    set payload(payload: Partial<Payload>);
    /**
     * Endpoint url for requests to update the payload
     */
    protected get endpoint_url(): string;
    protected set endpoint_url(value: string);
    /**
     * Fetches the objects data from it's endpoint
     * @returns The instance of the object
     */
    fetch(): Promise<this>;
    /**
     * Gets the value from the payload from its key
     * @param key The key to get the value of
     * @returns
     */
    protected get<P extends Payload, K extends keyof P>(key: K): Exclude<P[K], undefined> | null;
    /**
     * The unique id of the object
     */
    get id(): string;
    /**
     * Creates a new instance of the same structure with the same payload.
     * @returns A clone of the current instance
     */
    protected _clone(): this;
    valueOf(): string;
    /**
     *
     * @returns Converts the
     */
    toJSON(): string;
}
//# sourceMappingURL=Base.d.ts.map