/// <reference types="node" />
import { Messages } from "./Messages";
import { iFunnyErrorCodes } from "./iFunnyErrorCodes";
/**
 * Format the message for an error.
 * @param code The error code
 * @param args Arguments to pass for util format or as function args
 * @returns Formatted string
 */
declare function message<K extends keyof typeof Messages>(code: K, ...args: ResolveArgs<K>): string;
/**
 * Resolves arguments from Messages by its key
 */
declare type ResolveArgs<K extends keyof typeof Messages> = typeof Messages[K] extends (...args: any[]) => string ? Parameters<typeof Messages[K]> : any[];
export declare const iFunnyError: {
    new (code: iFunnyErrorCodes, ...args: any[]): {
        /**
         * The error code for the error
         */
        "__#1@#_code": iFunnyErrorCodes;
        /**
         * The error code for the error
         */
        readonly code: iFunnyErrorCodes;
        /**
         * The type of error
         */
        readonly error: string;
        /**
         * The name of the error
         */
        readonly name: string;
        createMessage<K extends iFunnyErrorCodes>(code: K, ...args: ResolveArgs<K>): string;
        message: string;
        stack?: string | undefined;
    };
    new<K_1 extends iFunnyErrorCodes>(code: K_1, ...args: ResolveArgs<K_1>): {
        /**
         * The error code for the error
         */
        "__#1@#_code": iFunnyErrorCodes;
        /**
         * The error code for the error
         */
        readonly code: iFunnyErrorCodes;
        /**
         * The type of error
         */
        readonly error: string;
        /**
         * The name of the error
         */
        readonly name: string;
        createMessage<K extends iFunnyErrorCodes>(code: K, ...args: ResolveArgs<K>): string;
        message: string;
        stack?: string | undefined;
    };
    /**
     * Easily create an unknown error
     * @param error Unknown error to turn into iFunny Error
     * @returns
     */
    unknown(error: unknown): {
        /**
         * The error code for the error
         */
        "__#1@#_code": iFunnyErrorCodes;
        /**
         * The error code for the error
         */
        readonly code: iFunnyErrorCodes;
        /**
         * The type of error
         */
        readonly error: string;
        /**
         * The name of the error
         */
        readonly name: string;
        createMessage<K extends iFunnyErrorCodes>(code: K, ...args: ResolveArgs<K>): string;
        message: string;
        stack?: string | undefined;
    };
    captureStackTrace(targetObject: object, constructorOpt?: Function | undefined): void;
    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;
    stackTraceLimit: number;
};
export declare const iFunnyTypeError: {
    new (code: iFunnyErrorCodes, ...args: any[]): {
        /**
         * The error code for the error
         */
        "__#1@#_code": iFunnyErrorCodes;
        /**
         * The error code for the error
         */
        readonly code: iFunnyErrorCodes;
        /**
         * The type of error
         */
        readonly error: string;
        /**
         * The name of the error
         */
        readonly name: string;
        createMessage<K extends iFunnyErrorCodes>(code: K, ...args: ResolveArgs<K>): string;
        message: string;
        stack?: string | undefined;
    };
    new<K_1 extends iFunnyErrorCodes>(code: K_1, ...args: ResolveArgs<K_1>): {
        /**
         * The error code for the error
         */
        "__#1@#_code": iFunnyErrorCodes;
        /**
         * The error code for the error
         */
        readonly code: iFunnyErrorCodes;
        /**
         * The type of error
         */
        readonly error: string;
        /**
         * The name of the error
         */
        readonly name: string;
        createMessage<K extends iFunnyErrorCodes>(code: K, ...args: ResolveArgs<K>): string;
        message: string;
        stack?: string | undefined;
    };
    /**
     * Easily create an unknown error
     * @param error Unknown error to turn into iFunny Error
     * @returns
     */
    unknown(error: unknown): {
        /**
         * The error code for the error
         */
        "__#1@#_code": iFunnyErrorCodes;
        /**
         * The error code for the error
         */
        readonly code: iFunnyErrorCodes;
        /**
         * The type of error
         */
        readonly error: string;
        /**
         * The name of the error
         */
        readonly name: string;
        createMessage<K extends iFunnyErrorCodes>(code: K, ...args: ResolveArgs<K>): string;
        message: string;
        stack?: string | undefined;
    };
    captureStackTrace(targetObject: object, constructorOpt?: Function | undefined): void;
    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;
    stackTraceLimit: number;
};
export declare const iFunnyRangeError: {
    new (code: iFunnyErrorCodes, ...args: any[]): {
        /**
         * The error code for the error
         */
        "__#1@#_code": iFunnyErrorCodes;
        /**
         * The error code for the error
         */
        readonly code: iFunnyErrorCodes;
        /**
         * The type of error
         */
        readonly error: string;
        /**
         * The name of the error
         */
        readonly name: string;
        createMessage<K extends iFunnyErrorCodes>(code: K, ...args: ResolveArgs<K>): string;
        message: string;
        stack?: string | undefined;
    };
    new<K_1 extends iFunnyErrorCodes>(code: K_1, ...args: ResolveArgs<K_1>): {
        /**
         * The error code for the error
         */
        "__#1@#_code": iFunnyErrorCodes;
        /**
         * The error code for the error
         */
        readonly code: iFunnyErrorCodes;
        /**
         * The type of error
         */
        readonly error: string;
        /**
         * The name of the error
         */
        readonly name: string;
        createMessage<K extends iFunnyErrorCodes>(code: K, ...args: ResolveArgs<K>): string;
        message: string;
        stack?: string | undefined;
    };
    /**
     * Easily create an unknown error
     * @param error Unknown error to turn into iFunny Error
     * @returns
     */
    unknown(error: unknown): {
        /**
         * The error code for the error
         */
        "__#1@#_code": iFunnyErrorCodes;
        /**
         * The error code for the error
         */
        readonly code: iFunnyErrorCodes;
        /**
         * The type of error
         */
        readonly error: string;
        /**
         * The name of the error
         */
        readonly name: string;
        createMessage<K extends iFunnyErrorCodes>(code: K, ...args: ResolveArgs<K>): string;
        message: string;
        stack?: string | undefined;
    };
    captureStackTrace(targetObject: object, constructorOpt?: Function | undefined): void;
    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;
    stackTraceLimit: number;
};
export declare const iFunnyErrorMessage: typeof message;
export {};
//# sourceMappingURL=iFunnyError.d.ts.map