import { APIUser, APIUserNums } from "@ifunny/ifunny-api-types";
import { Base } from "./Base";
import type { Client } from "../client/Client";
import { Collection } from "@discordjs/collection";
import { MemeExperience } from "./MemeExperience";
interface UserPayload extends Partial<APIUser> {
    id: APIUser["id"];
}
/**
 * Base User class that user class will inherit from.
 * @extends Base
 */
export declare class BaseUser extends Base<UserPayload> {
    /**
     * @param client The client instance
     * @param id The id of the user
     * @param payload Payload to create the User with
     */
    constructor(client: Client, id: string, payload?: any);
    /**
     * Is the user a partial
     */
    get partial(): boolean;
    /**
     * The user's about text
     * @alias bio
     */
    get about(): string | null;
    /**
     * @alias about
     */
    get bio(): string | null;
    /**
     * Does the user have you blocked?
     */
    get areYouBlocked(): boolean | null;
    /**
     * Collection of Bans the user has
     */
    get bans(): Collection<string, import("@ifunny/ifunny-api-types").APIBan> | null;
    /**
     * Cover image background color
     */
    get coverColor(): string | null;
    /**
     * Cover imamge url
     */
    get coverUrl(): string | null;
    /**
     * The user's unique id
     */
    get id(): string;
    /**
     * Can the Client chat with the user?\
     * ? Not checked by the backend
     */
    get isAvailableForChat(): boolean | null;
    /**
     * Is the user banned?
     */
    get isBanned(): boolean | null;
    /**
     * Is the user blocked by the Client?
     */
    get isBlocked(): boolean | null;
    /**
     * Is the user deleted?
     */
    get isDeleted(): boolean | null;
    /**
     * Is the user subscribed to the Client?
     */
    get isSubscriber(): boolean | null;
    /**
     * Is the client subscribed to the user?
     */
    get isSubscription(): boolean | null;
    /**
     * Is the user's account private?
     */
    get isPrivate(): boolean | null;
    /**
     * Is the user subscribed to updates?
     */
    get isSubscribedToUpdates(): boolean | null;
    /**
     * Is the user verified?
     */
    get isVerified(): boolean | null;
    /**
     * The user's meme experience
     */
    get memeExperience(): MemeExperience | null;
    /**
     * The user's chat privacy
     */
    get chatPrivacy(): "closed" | "public" | "subscribers" | null;
    /**
     * TODO: Add description for messengerActive
     */
    get messengerActive(): boolean | null;
    /**
     * TODO: Add description for messengerToken
     */
    get messengerToken(): string | null;
    /**
     * Nickname of the user
     * @alias username
     */
    get nick(): string | null;
    /**
     * Nickname of the user
     * @alias nick
     */
    get username(): string | null;
    /**
     * The nick color of the user if they have one, else null
     */
    get nickColor(): "55FF00" | "660000" | "ff3e52" | "a078f0" | "e0b400" | null;
    /**
     * The users {@link APIUserNums `num` } object
     * @alias `stats`
     */
    get num(): APIUserNums | null;
    /**
     * The users {@link APIUserNums `num` } object
     * @alias num
     */
    get stats(): APIUserNums | null;
    /**
     * The users subscription count\
     * ? `-1` = `unknown`
     */
    get totalSubscriptions(): number;
    /**
     * The users subsciber count\
     * ? `-1` = `unknown`
     */
    get totalSubscribers(): number;
    /**
     * How many posts the user has on their profile\
     * ? `-1` = `unknown`
     */
    get totalPosts(): number;
    /**
     * How many original posts the user has\
     * ? `-1` = `unknown`
     */
    get totalOriginalPosts(): number;
    /**
     * How many posts the has that are republishes (***NOT original***)\
     * ? `-1` = `unknown`
     */
    get totalRepublishedPosts(): number;
    /**
     * How many features the user has\
     * ? `-1` = `unknown`
     */
    get totalFeatures(): number;
    /**
     * How many smiles the user has on their profile\
     * ? `-1` = `unknown`
     */
    get totalSmiles(): number;
    /**
     * How many achievements the user has\
     * ? `-1` = `unknown`
     */
    get totalAchievements(): number;
}
export {};
//# sourceMappingURL=BaseUser.d.ts.map