import { APITokenType } from "@ifunny/ifunny-api-types";
declare const inspectSymbol: unique symbol;
export declare function capitalize(str: string): string;
export declare const BearerRegex: RegExp;
export declare const Basic112Regex: RegExp;
export declare const Basic156Regex: RegExp;
export declare const BasicRegex: RegExp;
interface TokenConfig {
    type: APITokenType;
    id: string;
    secret: string;
}
/**
 * Represents an auth token for the iFunny API.
 */
export declare class Token {
    protected _token: string;
    protected _config: TokenConfig;
    /**
     * @param token The auth token
     */
    constructor(token: string, config?: Partial<TokenConfig>);
    get config(): TokenConfig;
    /**
     * The value of the token
     */
    get value(): string;
    /**
     * The type of token this is\
     * Inferred from the token length
     */
    get type(): APITokenType;
    /**
     * The length of the token
     */
    get length(): number;
    /**
     * The regex it should pass to validate the token
     */
    get regex(): RegExp;
    /**
     * The string representation of the token
     * @example "Bearer <token>"
     * @example "Basic <token>"
     */
    toString(): string;
    [inspectSymbol](depth: number, opts: any, inspect: any): string;
    /**
     * Validates that the token passes the regex based on it's type `basic` | `bearer`
     * @param token Token to validate against the regex (Default: this.token)
     * @returns Is the token a valid
     */
    test(token?: string): boolean;
    /**
     * Compares a token to itself to see if they are equal
     * @param token Token to compare against
     * @returns
     */
    equals(token: Token | string): boolean;
    /**
     * Generates a basic token
     * @param opts Options to create the token with
     * @param opts.clientId The client id to use for the token
     * @param opts.clientSecret The client secret to use for the token
     * @param opts.length The length of the token to create
     * @returns
     */
    static generateBasic(opts?: {
        clientId?: string;
        clientSecret?: string;
        length?: 112 | 156;
    }): Token;
}
export {};
