import { AxiosError } from "axios";
import { BasicAuthConfig } from "./Util";
import { RESTAPIErrorResponse } from "@ifunny/ifunny-api-types";
/**
 * Certain requests have a header for 'if-modified-since' which uses the current timestamp
 * @param date Custom date
 * @returns GMT timestamp of the date
 */
export declare function ifModifiedSince(date?: Date): string;
/**
 * Asserts a claim to be true
 * @param claim The claim to check
 * @param error The message to send if the claim evaluted to false
 */
export declare function assert(claim: boolean, error: Error | string): claim is true;
/**
 * Validates that something is an Axios Error
 * @param item Item to validate
 */
export declare function isAxiosError<T extends RESTAPIErrorResponse = RESTAPIErrorResponse>(item: unknown): item is AxiosError<T>;
/**
 * Returns a Date object from a timestamp
 * @param timestamp Number of seconds of the timestamp
 * @param inMilliseconds Whether the timestamp is already in milliseconds or not
 * @returns
 */
export declare function dateFromTimestamp(timestamp: number, inMilliseconds?: boolean): Date;
/**
 * Sleeps the program for the specified amount of milliseconds
 * @param ms The number of milliseconds to wait
 * @returns A promise that resolves after the given amount of time
 */
export declare function sleep(ms: number): Promise<void>;
/**
 * Generates a basic token
 * @param opts Options to create the token with
 * @param opts.clientId The client id to use for the token
 * @param opts.clientSecret The client secret to use for the token
 * @param opts.length The length of the token to create
 * @returns
 */
export declare function createBasicAuth(opts?: BasicAuthConfig): string;
//# sourceMappingURL=Methods.d.ts.map