/**
 * All primitive types in JS
 */
export declare type Primitive = string | number | boolean | null | undefined;
/**
 * Primitives that are not undefined
 */
export declare type SafePrimitive = Exclude<Primitive, undefined>;
/**
 * Array that can be safely used in a JSON object
 */
export interface JSONArray extends Array<JSONValue> {
}
/**
 * Value that can be safely used in a JSON object
 */
export declare type JSONValue = SafePrimitive | JSONArray | JSONObject;
/**
 * JSON safe plain object
 */
export interface JSONObject {
    [key: string]: JSONValue | JSONObject | JSONObject[];
}
/**
 * Conditional type that can be checked at compile time
 */
export declare type If<T extends boolean, A, B = null> = T extends true ? A : T extends false ? B : A | B;
export declare type BasicAuthLength = 112 | 156;
export declare type BasicAuthConfig = {
    clientId: string;
    clientSecret: string;
    length: BasicAuthLength;
};
//# sourceMappingURL=Util.d.ts.map